import PageObject from './page-object';
import type { PageObjectConstructor } from './-private/types';
/**
 * Define a {@link PageObject} with a global scope, i.e. not scoped by its
 * parent page object. Useful for cases like popovers and dropdowns, where the
 * UI control is logically inside a given component, but all or part of it
 * renders elsewhere in the DOM, such as directly under the body.
 * {@link globalSelector} accepts a selector and optional custom class like
 * {@link selector()}, but the queries of the page objects it generates will be
 * executed from the root (`document.body` or whatever was passed to
 * {@link setRoot}) rather than the parent page object's elements.
 *
 * In some cases, it makes sense to set up a global root using {@link setRoot},
 * but some elements might be rendered outside even that, such as directly under
 * the body. For cases like this, {@link globalSelector} accepts an optional
 * root element to use as the root of the queries of the page object it
 * generates.
 *
 * @param {string} selector the selector
 * @param {Function<PageObject>} [Class] optional {@link PageObject} subclass that
 * can be used to extend the functionality of this page object
 *
 * @returns {PageObject} a {@link PageObject} or {@link PageObject} subclass
 * instance
 */
export default function globalSelector<T extends PageObject>(selector: string, Class?: PageObjectConstructor<T>): T;
/**
 * Define a {@link PageObject} with a global scope, i.e. not scoped by its
 * parent page object. Useful for cases like popovers and dropdowns, where the
 * UI control is logically inside a given component, but all or part of it
 * renders elsewhere in the DOM, such as directly under the body.
 * {@link globalSelector} accepts a selector and optional custom class like
 * {@link selector()}, but the queries of the page objects it generates will be
 * executed from the root (`document.body` or whatever was passed to
 * {@link setRoot}) rather than the parent page object's elements.
 *
 * In some cases, it makes sense to set up a global root using {@link setRoot},
 * but some elements might be rendered outside even that, such as directly under
 * the body. For cases like this, {@link globalSelector} accepts an optional
 * root element to use as the root of the queries of the page object it
 * generates.
 *
 * @param {string} selector the selector
 * @param {Element} rootElement the root element under which to query the
 * selector.
 * @param {Function<PageObject>} Class optional {@link PageObject} subclass that
 * can be used to extend the functionality of this page object
 *
 * @returns {PageObject} a {@link PageObject} or {@link PageObject} subclass
 * instance
 */
export default function globalSelector<T extends PageObject>(selector: string, rootElement: Element, Class?: PageObjectConstructor<T>): T;
